
[![PyPI status](https://img.shields.io/pypi/status/dpytools.svg)](https://pypi.python.org/pypi/dpytools/)
[![PyPI version fury.io](https://badge.fury.io/py/dpytools.svg)](https://pypi.python.org/pypi/dpytools/)
[![PyPI downloads](https://img.shields.io/pypi/dm/dpytools.svg)](https://pypistats.org/packages/dpytools)
[![PyPI license](https://img.shields.io/pypi/l/dpytools.svg)](https://pypi.python.org/pypi/dpytools/)


# dpytools
Collection of tools to speed up developing discord bots using discord.py

# Features
- Easy to read typehinted code
- Active development

## Main components
- checks - commands' checks
- commands - Commands that are so frequent, why code them every time when you can just import them from dpytools
- menus - Reaction menus to improve your commands
- parsers - Functions and converters for use as typehints in command arguments so that you don't have to deal with parsing 

# Instalation
Install the latest version of the library with pip.
```
pip install -U dpytools
```

# Useful links:
- [List](https://github.com/chrisdewa/dpytools/blob/master/docs/All.md) of all the available tools.
- [Project Home](https://github.com/chrisdewa/dpytools) on github
- [Changelog](https://github.com/chrisdewa/dpytools/blob/master/CHANGELOG.md)
- [F. A. Q.](https://github.com/chrisdewa/dpytools/blob/master/docs/FAQ.md) and examples

# Status of the project
Early development. 
Only use in production after extensive testing.
Expect breaking changes with future updates

# Contributing
Feel free to make a pull request or rise any issues.

# Contact
Message me on discord at **ChrisDewa#4552** if you have any questions, ideas or suggestions.
